/virtualbox/{uuid}/capture/{port_id:d+}/start — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /virtualbox/{uuid}/capture/{port_id:d+}/start

Contents

- /virtualbox/{uuid}/capture/{port_id:d+}/start
  - POST /virtualbox/{uuid}/capture/{port_id:d+}/start
    - Parameters
    - Response status codes
    - Input

## POST /virtualbox/{uuid}/capture/{port_id:d+}/start

Start a packet capture on a VirtualBox VM instance

### Parameters

- uuid: Instance UUID
- port_id: ID of the port to start a packet capture

### Response status codes

- 200: Capture started
- 400: Invalid instance UUID
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
capture_filename | ✔ | string | Capture file name

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »